package de.intevation.artifacts;

/**
 * Interface of an artifact managing database.
 *
 * @author Sascha L. Teichmann (sascha.teichmann@intevation.de)
 */
public interface ArtifactDatabase
{
    /**
     * List of artifact factories names accessible through the database.
     * @return names of the factories.
     */
    String [] getArtifactFactoryNames();

    /**
     * Look up an artifact by its identifier.
     * @return the artifact. null if the artifact is not found.
     */
    Artifact getArtifact(String identifier);

    /**
     * Creates new artifact with a certain factory.
     * @param factoryName the name of the factory. Name out of {@link #getArtifactFactoryNames() getArtifactFactoryNames()}.
     */
    Artifact createArtifactWithFactory(String factoryName);


    /**
     * Returns the global artifact runtime context.
     * @return the runtime context
     */
    Object getArtifactContext();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
